@@ -9,7 +9,7 @@
 -- domain-specific language for describing and rendering diagrams.
 -- Normal users of the diagrams library should almost never need to
 -- import anything from this package directly; instead, import modules
--- (especially "Diagrams.Prelude") from the diagrams-lib package,
+-- (especially @Diagrams.Prelude@) from the diagrams-lib package,
 -- which re-exports most things of value to users.
 --
 -- For most library code needing access to core internals, it should
@@ -29,15 +29,22 @@ module Diagrams.Core
          -- * Points
 
        , Point, origin, (*.)
+       , _relative
 
          -- * Transformations
 
+         -- ** Utilities
+       , basis
+       , dimension
+       , determinant
+
          -- ** Invertible linear transformations
        , (:-:), (<->), linv, lapp
 
          -- ** General transformations
        , Transformation
        , inv, transp, transl
+       , dropTransl
        , apply
        , papply
        , fromLinear
@@ -45,6 +52,7 @@ module Diagrams.Core
          -- ** Some specific transformations
        , translation, translate, moveTo, place
        , scaling, scale
+       , avgScale
 
          -- ** The Transformable class
 
@@ -52,7 +60,7 @@ module Diagrams.Core
 
          -- ** Translational invariance
 
-       , TransInv(..)
+       , TransInv(TransInv)
 
          -- * Names
 
@@ -71,27 +79,30 @@ module Diagrams.Core
          -- * Attributes and styles
 
        , AttributeClass
-       , Attribute, mkAttr, mkTAttr, unwrapAttr
+       , Attribute, mkAttr, mkTAttr, mkGTAttr, unwrapAttr
 
        , Style, HasStyle(..)
        , getAttr, combineAttr
-       , applyAttr, applyTAttr
+       , applyAttr, applyTAttr, applyGTAttr
 
          -- * Envelopes
 
-       , Envelope
-       , inEnvelope, appEnvelope, onEnvelope, mkEnvelope
+       , Envelope(..)
+       , appEnvelope, onEnvelope, mkEnvelope
        , Enveloped(..)
        , envelopeVMay, envelopeV, envelopePMay, envelopeP
        , diameter, radius
 
          -- * Traces
 
-       , Trace(..)
-       , inTrace, mkTrace
+       , Trace(Trace)
+       , SortedList, mkSortedList, getSortedList
+       , appTrace, mkTrace
        , Traced(..)
        , traceV, traceP
        , maxTraceV, maxTraceP
+       , rayTraceV, rayTraceP
+       , maxRayTraceV, maxRayTraceP
 
          -- * Things with local origins
 
@@ -107,12 +118,11 @@ module Diagrams.Core
 
          -- * Primtives
 
-       , Prim(..), IsPrim(..), nullPrim
+       , Prim(..)
 
          -- * Diagrams
 
-       , QDiagram, mkQD, Diagram
-       , prims
+       , QDiagram, Diagram, mkQD, pointDiagram
        , envelope, trace, subMap, names, query, sample
        , value, resetValue, clearValue
 
@@ -122,7 +132,9 @@ module Diagrams.Core
        , withNames
        , localize
 
-       , freeze, setEnvelope, setTrace
+       , href
+
+       , setEnvelope, setTrace
 
        , atop
 
@@ -133,12 +145,21 @@ module Diagrams.Core
        , location
        , subPoint
 
+         -- * Measurements
+       , Measure(..)
+       , fromOutput
+       , toOutput
+       , atMost
+       , atLeast
+
          -- * Backends
 
        , Backend(..)
-       , MultiBackend(..)
        , Renderable(..)
 
+       , renderDia
+       , renderDiaT
+
          -- ** The null backend
 
        , NullBackend, D
@@ -151,6 +172,7 @@ module Diagrams.Core
 
        ) where
 
+import           Diagrams.Core.Compile
 import           Diagrams.Core.Envelope
 import           Diagrams.Core.HasOrigin
 import           Diagrams.Core.Juxtapose
