@@ -2,7 +2,10 @@
 {-# LANGUAGE FlexibleInstances          #-}
 {-# LANGUAGE GADTs                      #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
+{-# LANGUAGE MultiParamTypeClasses      #-}
 {-# LANGUAGE OverlappingInstances       #-}
+{-# LANGUAGE TemplateHaskell            #-}
+{-# LANGUAGE TypeFamilies               #-}
 {-# LANGUAGE TypeSynonymInstances       #-}
 -----------------------------------------------------------------------------
 -- |
@@ -29,8 +32,11 @@ module Diagrams.Core.Names
 
        ) where
 
+import           Control.Lens            (over, Wrapped(..), Rewrapped, iso, _Unwrapping')
 import           Data.List               (intercalate)
+import qualified Data.Map                as M
 import           Data.Semigroup
+import qualified Data.Set                as S
 import           Data.Typeable
 
 import           Diagrams.Core.Transform
@@ -87,6 +93,12 @@ instance Show AName where
 newtype Name = Name [AName]
   deriving (Eq, Ord, Semigroup, Monoid, Typeable)
 
+instance Wrapped Name where
+    type Unwrapped Name = [AName]
+    _Wrapped' = iso (\(Name ans) -> ans) Name
+
+instance Rewrapped Name Name
+
 instance Show Name where
   show (Name ns) = intercalate " .> " $ map show ns
 
@@ -110,7 +122,25 @@ instance Qualifiable Name where
   (|>) = (.>)
 
 instance Qualifiable a => Qualifiable (TransInv a) where
-  (|>) n = TransInv . (|>) n . unTransInv
+  (|>) n = over (_Unwrapping' TransInv) (n |>)
+
+instance (Qualifiable a, Qualifiable b) => Qualifiable (a,b) where
+  n |> (a,b) = (n |> a, n |> b)
+
+instance (Qualifiable a, Qualifiable b, Qualifiable c) => Qualifiable (a,b,c) where
+  n |> (a,b,c) = (n |> a, n |> b, n |> c)
+
+instance Qualifiable a => Qualifiable [a] where
+  n |> as = map (n |>) as
+
+instance (Ord a, Qualifiable a) => Qualifiable (S.Set a) where
+  n |> s = S.map (n |>) s
+
+instance Qualifiable a => Qualifiable (M.Map k a) where
+  n |> m = fmap (n |>) m
+
+instance Qualifiable a => Qualifiable (b -> a) where
+ n |> f = (n |>) . f
 
 infixr 5 |>
 infixr 5 .>
