@@ -1,5 +1,7 @@
-{-# LANGUAGE TypeFamilies
-  #-}
+{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE RankNTypes #-}
+{-# LANGUAGE TypeFamilies #-}
+
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Diagrams.Core.Points
@@ -15,14 +17,24 @@ module Diagrams.Core.Points
        ( -- * Points
 
          Point(..), origin, (*.)
+       , _relative
 
        ) where
 
--- We just import from Data.AffineSpace.Point (defined in the
+-- We import from Data.AffineSpace.Point (defined in the
 -- vector-space-points package) and re-export.  We also define an
 -- instance of V for Point here.
+
+import Control.Lens (Iso', iso)
+
 import Data.AffineSpace.Point
+import Data.AffineSpace
 
 import Diagrams.Core.V
 
-type instance V (Point v) = v
\ No newline at end of file
+type instance V (Point v) = v
+
+-- | An isomorphism between points and vectors, given a reference
+-- point.  This is provided for defining new lenses on points.
+_relative :: AffineSpace (Point v) => Point v -> Iso' (Point v) v
+_relative p0 = iso (.-. p0) (p0 .+^)
